# Repo Structure

- `benchmarks/`
  - This directory contains microbenchmarks for each kernel/op in Conch
- `conch/`
  - See [Conch docs](/docs/conch/structure.md) for more info about the Conch package structure
- `dist/`
  - This directory contains distribution files (wheels, source archives, etc.)
- `docs/`
  - This directory contains documentation in markdown format
- `results/`
  - This directory contains benchmarking CSV result files and plots
- `tests/`
  - This directory contains unit tests for each kernel/op in Conch
- `tools/`
  - This directory contains misc tools (e.g. plotting benchmark results) and scripts for easing the developer experience
